@@ -1,27 +1,26 @@
-"""
-Simulates and animates tilemap movements from a start node to a target node,
-either in one timestep (no visualizer set),
-or in steps of a configurable length (visualizer set).
-"""
 import math
 import operator
 from typing import Any, List, Optional
+
+import simpy
+from casymda.blocks.block_components import VisualizableBlock
+from .coordinates_holder import CoordinatesHolder
+from casymda.blocks.tilemap.segment import Segment
 from casymda.environments.realtime_environment import (
     ChangeableFactorRealtimeEnvironment,
 )
-
-import simpy
-from simpy import RealtimeEnvironment
-
-from casymda.blocks.block_components import VisualizableBlock
-from casymda.blocks.tilemap.coordinates_holder import CoordinatesHolder
-from casymda.blocks.tilemap.segment import Segment
 from casymda.visualization.tilemap.tilemap_visualizer_interface import (
     TilemapVisualizerInterface as TilemapVisualizer,
 )
+from simpy import RealtimeEnvironment
 
 
 class TilemapMovement(VisualizableBlock):
+    """
+    Simulates and animates tilemap movements from a start node to a target node,
+    either in one timestep (no visualizer set),
+    or in steps of a configurable length (visualizer set).
+    """
 
     MAX_ANIMATION_TIMESTEP = 0.1
 
@@ -36,8 +35,9 @@ class TilemapMovement(VisualizableBlock):
         to_node="",
         ways={},
         destroy_anim_on_arrival=True,
+        block_capacity=float("inf"),
     ):
-        super().__init__(env, name, xy=xy, ways=ways)
+        super().__init__(env, name, xy=xy, ways=ways, block_capacity=block_capacity)
 
         self.speed = speed
         if coordinates_holder is None:
@@ -57,30 +57,37 @@ class TilemapMovement(VisualizableBlock):
             self.from_node, self.to_node
         )
 
+        speed = self.speed
+
         animation_loop: Any = None
         if self.tilemap_visualizer is not None:
             animation_loop = self.env.process(
                 self.animation_loop(
-                    entity, path_coords, destroy_on_arrival=self.destroy_anim_on_arrival
-                )
+                    entity,
+                    path_coords,
+                    destroy_on_arrival=self.destroy_anim_on_arrival,
+                    speed=speed,
+                )  # run animation seperately if required
             )
 
-        time_needed = overall_length / self.speed
+        time_needed = overall_length / speed
         yield self.env.timeout(time_needed)
 
         if self.tilemap_visualizer is not None:
-            animation_loop.interrupt()
+            animation_loop.interrupt()  # stop animation running "in parallel"
 
-    # ...animation-related stuff down here:
+    def animation_loop(
+        self, entity, path_coords, destroy_on_arrival: bool = True, speed=None
+    ):
+        if speed is None:
+            speed = self.speed
 
-    def animation_loop(self, entity, path_coords, destroy_on_arrival: bool = True):
         self.tilemap_visualizer.destroy(entity)  # recreate possibly existing animations
-        segments = self.get_segments(path_coords)
+        segments = self.get_segments(path_coords, speed)
         time_spent = 0
-        # while not interupted
         try:
-            while True:
-                self.calc_progress_and_animate(entity, segments, time_spent)
+            while True:  # while not interupted:
+                self.calc_progress_and_animate(entity, segments, time_spent, speed)
 
                 self.set_animation_timestep()
                 yield self.env.timeout(self.MAX_ANIMATION_TIMESTEP)
@@ -92,8 +99,10 @@ class TilemapMovement(VisualizableBlock):
             if destroy_on_arrival:
                 self.tilemap_visualizer.destroy(entity)
 
-    def calc_progress_and_animate(self, entity, segments: List[Segment], time_spent):
-        distance = self.speed * time_spent
+    def calc_progress_and_animate(
+        self, entity, segments: List[Segment], time_spent, speed
+    ):
+        distance = speed * time_spent
         current_segment = segments[-1]
         for segment in segments:
             current_segment = segment
@@ -122,10 +131,10 @@ class TilemapMovement(VisualizableBlock):
             self.env, RealtimeEnvironment
         ):
             self.MAX_ANIMATION_TIMESTEP = 0.04 / self.env.factor
-            # keep reference to the factor -> change animation timestep dynamically, if visualized, for a smooth dynamic animation
+            # keep reference to the factor -> change animation timestep dynamically if visualized (for a smooth animation)
 
-    def get_segments(self, path_coords):
-        """pre-compute needed segment information"""
+    def get_segments(self, path_coords, speed):
+        """pre-compute needed segment information for the animation"""
         segments = []
         cumulated_length = 0
         cumulated_time = 0
@@ -135,7 +144,7 @@ class TilemapMovement(VisualizableBlock):
             direction = tuple(map(operator.sub, destination, origin))
             squared = map((lambda x: x ** 2), direction)
             length = math.sqrt(sum(squared))
-            time_needed = length / self.speed
+            time_needed = length / speed
 
             cumulated_length += length
             cumulated_time += time_needed
